@@ -22,7 +22,7 @@
 #========================================================================
 
 package Pod::POM::Constants;
-$Pod::POM::Constants::VERSION = '2.00';
+$Pod::POM::Constants::VERSION = '2.01';
 require 5.006;
 
 use strict;
@@ -57,7 +57,7 @@ use constant REJECT => 2;
 
 =head1 NAME
 
-Pod::POM::Constants
+Pod::POM::Constants - constants used for Pod::POM
 
 =head1 DESCRIPTION
 
