@@ -21,7 +21,7 @@
 #========================================================================
 
 package Pod::POM::View;
-$Pod::POM::View::VERSION = '2.00';
+$Pod::POM::View::VERSION = '2.01';
 require 5.006;
 
 use strict;
@@ -127,7 +127,7 @@ sub AUTOLOAD {
 
 =head1 NAME
 
-Pod::POM::View
+Pod::POM::View - view POM objects
 
 =head1 DESCRIPTION
 
