@@ -20,7 +20,7 @@
 #========================================================================
 
 package Pod::POM::View::Text;
-$Pod::POM::View::Text::VERSION = '2.00';
+$Pod::POM::View::Text::VERSION = '2.01';
 require 5.006;
 use strict;
 use warnings;
@@ -267,7 +267,7 @@ sub view_seq_link {
 
 =head1 NAME
 
-Pod::POM::View::Text
+Pod::POM::View::Text - create text views of POM objects
 
 =head1 DESCRIPTION
 
